@@ -6,6 +6,7 @@ from .driver import annotate_task
 from .exceptions import BadFunctionError
 from .interface import (
     AutoAnnotationFunction,
+    DetectionAnnotation,
     DetectionFunction,
     DetectionFunctionContext,
     DetectionFunctionSpec,
@@ -27,6 +28,7 @@ from .interface import (
     shape,
     skeleton,
     skeleton_label_spec,
+    tag,
     text_attribute_spec,
 )
 
@@ -36,6 +38,7 @@ __all__ = [
     "attribute_spec",
     "BadFunctionError",
     "checkbox_attribute_spec",
+    "DetectionAnnotation",
     "DetectionFunction",
     "DetectionFunctionContext",
     "DetectionFunctionSpec",
@@ -55,5 +58,6 @@ __all__ = [
     "shape",
     "skeleton_label_spec",
     "skeleton",
+    "tag",
     "text_attribute_spec",
 ]
