@@ -1,4 +1,4 @@
-# Copyright (C) 2022-2023 CVAT.ai Corporation
+# Copyright (C) CVAT.ai Corporation
 #
 # SPDX-License-Identifier: MIT
 
@@ -7,13 +7,15 @@ from __future__ import annotations
 import io
 import json
 from pathlib import Path
-from typing import TYPE_CHECKING, List, Optional
+from typing import TYPE_CHECKING, Optional
 
 from cvat_sdk.api_client import apis, models
-from cvat_sdk.core.downloading import Downloader
 from cvat_sdk.core.helpers import get_paginated_collection
 from cvat_sdk.core.progress import ProgressReporter
 from cvat_sdk.core.proxies.model_proxy import (
+    DownloadBackupMixin,
+    ExportDatasetMixin,
+    ModelBatchDeleteMixin,
     ModelCreateMixin,
     ModelDeleteMixin,
     ModelListMixin,
@@ -37,6 +39,8 @@ class Project(
     models.IProjectRead,
     ModelUpdateMixin[models.IPatchedProjectWriteRequest],
     ModelDeleteMixin,
+    ExportDatasetMixin,
+    DownloadBackupMixin,
 ):
     _model_partial_update_arg = "patched_project_write_request"
 
@@ -45,86 +49,33 @@ class Project(
         format_name: str,
         filename: StrPath,
         *,
+        conv_mask_to_poly: Optional[bool] = None,
         status_check_period: Optional[int] = None,
         pbar: Optional[ProgressReporter] = None,
     ):
         """
-        Import dataset for a project in the specified format (e.g. 'YOLO ZIP 1.0').
+        Import dataset for a project in the specified format (e.g. 'YOLO 1.1').
         """
 
         filename = Path(filename)
 
         DatasetUploader(self._client).upload_file_and_wait(
             self.api.create_dataset_endpoint,
-            self.api.retrieve_dataset_endpoint,
             filename,
             format_name,
             url_params={"id": self.id},
+            conv_mask_to_poly=conv_mask_to_poly,
             pbar=pbar,
             status_check_period=status_check_period,
         )
 
         self._client.logger.info(f"Annotation file '{filename}' for project #{self.id} uploaded")
 
-    def export_dataset(
-        self,
-        format_name: str,
-        filename: StrPath,
-        *,
-        pbar: Optional[ProgressReporter] = None,
-        status_check_period: Optional[int] = None,
-        include_images: bool = True,
-    ) -> None:
-        """
-        Download annotations for a project in the specified format (e.g. 'YOLO ZIP 1.0').
-        """
-
-        filename = Path(filename)
-
-        if include_images:
-            endpoint = self.api.retrieve_dataset_endpoint
-        else:
-            endpoint = self.api.retrieve_annotations_endpoint
-
-        Downloader(self._client).prepare_and_download_file_from_endpoint(
-            endpoint=endpoint,
-            filename=filename,
-            url_params={"id": self.id},
-            query_params={"format": format_name},
-            pbar=pbar,
-            status_check_period=status_check_period,
-        )
-
-        self._client.logger.info(f"Dataset for project {self.id} has been downloaded to {filename}")
-
-    def download_backup(
-        self,
-        filename: StrPath,
-        *,
-        status_check_period: int = None,
-        pbar: Optional[ProgressReporter] = None,
-    ) -> None:
-        """
-        Download a project backup
-        """
-
-        filename = Path(filename)
-
-        Downloader(self._client).prepare_and_download_file_from_endpoint(
-            self.api.retrieve_backup_endpoint,
-            filename=filename,
-            pbar=pbar,
-            status_check_period=status_check_period,
-            url_params={"id": self.id},
-        )
-
-        self._client.logger.info(f"Backup for project {self.id} has been downloaded to {filename}")
-
     def get_annotations(self) -> models.ILabeledData:
         (annotations, _) = self.api.retrieve_annotations(self.id)
         return annotations
 
-    def get_tasks(self) -> List[Task]:
+    def get_tasks(self) -> list[Task]:
         return [
             Task(self._client, m)
             for m in get_paginated_collection(
@@ -132,7 +83,7 @@ class Project(
             )
         ]
 
-    def get_labels(self) -> List[models.ILabel]:
+    def get_labels(self) -> list[models.ILabel]:
         return get_paginated_collection(
             self._client.api_client.labels_api.list_endpoint, project_id=self.id
         )
@@ -149,6 +100,7 @@ class ProjectsRepo(
     ModelCreateMixin[Project, models.IProjectWriteRequest],
     ModelListMixin[Project],
     ModelRetrieveMixin[Project],
+    ModelBatchDeleteMixin,
 ):
     _entity_type = Project
 
@@ -160,6 +112,7 @@ class ProjectsRepo(
         dataset_format: str = "CVAT XML 1.1",
         status_check_period: int = None,
         pbar: Optional[ProgressReporter] = None,
+        conv_mask_to_poly: Optional[bool] = None,
     ) -> Project:
         """
         Create a new project with the given name and labels JSON and
@@ -176,6 +129,7 @@ class ProjectsRepo(
                 filename=dataset_path,
                 pbar=pbar,
                 status_check_period=status_check_period,
+                conv_mask_to_poly=conv_mask_to_poly,
             )
 
         project.fetch()
@@ -210,16 +164,13 @@ class ProjectsRepo(
             logger=self._client.logger.debug,
         )
 
-        rq_id = json.loads(response.data)["rq_id"]
-        response = self._client.wait_for_completion(
-            url,
-            success_status=201,
-            positive_statuses=[202],
-            post_params={"rq_id": rq_id},
-            status_check_period=status_check_period,
+        rq_id = json.loads(response.data).get("rq_id")
+        assert rq_id, "The rq_id was not found in server response"
+        request, response = self._client.wait_for_completion(
+            rq_id, status_check_period=status_check_period
         )
 
-        project_id = json.loads(response.data)["id"]
+        project_id = request.result_id
         self._client.logger.info(
             f"Project has been imported successfully. Project ID: {project_id}"
         )
